@@ -1,4 +1,4 @@
-# Gufw 11.04.1 - http://gufw.tuxfamily.org
+# Gufw 11.04.2 - http://gufw.tuxfamily.org
 # Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -20,8 +20,11 @@ import threading
 import gobject
 import dbus
 import webbrowser
-from gettext import gettext as _
+import gettext
 from util    import Path
+from gettext import gettext as _
+
+gettext.textdomain('gufw')
 
 __color__ = { "gray"   : "#BAB5AB",  # Basic 3D Medium
               "green"  : "#267726",  # Accent Green Dark
@@ -33,7 +36,7 @@ __color__ = { "gray"   : "#BAB5AB",  # Basic 3D Medium
 class GuiGufw:
     """All events"""
     FONT = "ubuntu 10"
-    TIME_REFRESH_REPORT = 1000
+    TIME_REFRESH_REPORT = 1200
     TIME_STATUS_BAR = 8
     
     def __init__(self, firewall):
@@ -90,29 +93,32 @@ class GuiGufw:
         self.menu_edit      = builder.get_object("menu_edit")
         self.menu_help      = builder.get_object("menu_help")
         # Menu
-        self.menu_log       = builder.get_object("menuLogObject")
-        self.menu_quit      = builder.get_object("menuQuit")
-        self.menu_add       = builder.get_object("menuAddObject")
-        self.menu_remove    = builder.get_object("menuRemoveObject")
-        self.menu_reset     = builder.get_object("menuResetObject")
-        self.menu_pref      = builder.get_object("menuPreferencesObject")
+        self.menu_log       = builder.get_object("menuLog")
+        self.menu_quit      = builder.get_object("actionQuit")
+        self.menu_add       = builder.get_object("menuAdd")
+        self.menu_remove    = builder.get_object("menuRemove")
+        self.menu_reset     = builder.get_object("menuReset")
+        self.menu_pref      = builder.get_object("menuPreferences")
         self.menu_doc       = builder.get_object("menuDoc")
-        self.menu_answers   = builder.get_object("menuHelp")
+        self.menu_answers   = builder.get_object("menuAnswers")
+        self.menu_bug       = builder.get_object("menuBug")
         self.menu_translate = builder.get_object("menuTranslate")
-        self.menu_about     = builder.get_object("menuAbout")
+        self.menu_about     = builder.get_object("actionAbout")
         # Disable menus (not works from Glade)
         self.menu_log.set_sensitive(0)
         self.menu_add.set_sensitive(0)
         self.menu_remove.set_sensitive(0)
         self.menu_reset.set_sensitive(0)
         self.menu_pref.set_sensitive(0)
+        # Problems with the Glade events
+        self.menu_doc.set_sensitive(0)
+        self.menu_answers.set_sensitive(0)
+        self.menu_bug.set_sensitive(0)
+        self.menu_translate.set_sensitive(0)
         # Set minimial signals for launch Gufw
         self.btn_unblock.connect('clicked', self.on_btnUnblock_clicked)
         self.win_main.connect('delete-event', self.on_winMain_delete_event)
         self.menu_quit.connect('activate', self.on_menuQuit_activate)
-        self.menu_doc.connect('activate', self.on_menuDoc_activate)
-        self.menu_answers.connect('activate', self.on_menuHelp_activate)
-        self.menu_translate.connect('activate', self.on_menuTranslate_activate)
         self.menu_about.connect('activate', self.on_menuAbout_activate)
         # Show Listening report
         if self.fw.get_listening_status() == "enable":
@@ -125,7 +131,7 @@ class GuiGufw:
         self.render_txt = gtk.CellRendererText()
         self.render_txt.set_property("font", self.FONT)
         
-        self.rules_model = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING,
+        self.rules_model = gtk.ListStore(gobject.TYPE_INT,    gobject.TYPE_STRING, gobject.TYPE_STRING,
                                          gobject.TYPE_STRING, gobject.TYPE_STRING)
         
         self.tv_rules = builder.get_object("tvRules")
@@ -145,7 +151,7 @@ class GuiGufw:
         self.tv_rules.append_column (tree_header)
         
         # Listening Report
-        self.report_model = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING,
+        self.report_model = gtk.ListStore(gobject.TYPE_INT,    gobject.TYPE_STRING, gobject.TYPE_STRING,
                                           gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING) 
         self.tv_report = builder.get_object("tvReport")
         self.tv_report.set_model(self.report_model)
@@ -411,6 +417,12 @@ class GuiGufw:
     
     def _do_refresh_report(self):
         """Refresh method in background (no freeze)"""
+        if self.fw.get_listening_status() == "disable":
+            self.previus_report = []
+            self.first_run_report = True
+            self.report_model.clear()
+            return False
+        
         lines = self.fw.get_listening_report()
         background_job = RefreshReport(self.fw.get_status(), self.report_model, lines, self.previus_report, self.first_run_report, self.fw.get_notify_popup())
         background_job.start()
@@ -418,11 +430,7 @@ class GuiGufw:
         if self.fw.get_listening_status() == "enable":
             self.first_run_report = False
             return True
-        else:
-            self.previus_report = []
-            self.first_run_report = True
-            return False
-    
+        
     def _refresh_report(self):
         """Refresh Listening Report"""
         gobject.timeout_add(self.TIME_REFRESH_REPORT , self._do_refresh_report)
@@ -768,8 +776,7 @@ class GuiGufw:
             self._set_initial_objects_preferences()
             self._set_main_values("")
             self.ui_builder.connect_signals(self)
-            if self.fw.get_listening_status() == "enable":
-                self._refresh_report()
+            self._refresh_report()
         else:
             self._set_statusbar_msg(_("Wrong identification"))
         
@@ -781,6 +788,11 @@ class GuiGufw:
         self.menu_reset.set_sensitive(1)
         self.menu_pref.set_sensitive(1)
         self.btn_add_window.set_sensitive(1)
+        # Problems with Glade events
+        self.menu_doc.set_sensitive(1)
+        self.menu_answers.set_sensitive(1)
+        self.menu_bug.set_sensitive(1)
+        self.menu_translate.set_sensitive(1)
         # Status
         self.cb_enabled_firewall.set_sensitive(1)
         if self.fw.get_status() == "enable":
@@ -995,6 +1007,9 @@ class GuiGufw:
         """Menu Quit"""
         width, height = self.win_main.get_size()
         self.fw.update_config_file(width, height, self.vpanelmain.get_position())
+        if self.fw.get_listening_status() != "disable":
+            self.fw.set_listening_status("disable")
+            self._refresh_report()
         gtk.main_quit()
     
     def on_menuAdd_activate(self,widget):
@@ -1057,7 +1072,7 @@ class GuiGufw:
         """Launch browser with Documentation web"""
         webbrowser.open_new("https://help.ubuntu.com/community/Gufw")
         
-    def on_menuHelp_activate(self, widget):
+    def on_menuAnswers_activate(self, widget):
         """Launch browser with Documentation web"""
         webbrowser.open_new("https://answers.launchpad.net/gui-ufw")
         
@@ -1065,10 +1080,17 @@ class GuiGufw:
         """Launch browser with Documentation web"""
         webbrowser.open_new("https://translations.launchpad.net/gui-ufw/trunk/+translations")
         
+    def on_menuBug_activate(self, widget):
+        """Launch browser with Bug Report web"""
+        webbrowser.open_new("https://bugs.launchpad.net/gui-ufw")
+        
     def on_winMain_delete_event(self, widget, event):
         """Close Button Main Window"""
         width, height = self.win_main.get_size()
         self.fw.update_config_file(width, height, self.vpanelmain.get_position())
+        if self.fw.get_listening_status() != "disable":
+            self.fw.set_listening_status("disable")
+            self._refresh_report()
         gtk.main_quit()
     
     def on_winAdd_delete_event(self, widget, event):
